@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2007-2008, 2010-2012, 2014-2017 Free
+   Copyright (C) 1999, 2001, 2007-2008, 2010-2012, 2014-2018 Free
    Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -34,6 +34,6 @@ imap4d_logout (struct imap4d_session *session,
 {
   if (imap4d_tokbuf_argc (tok) != 2)
     return io_completion_response (command, RESP_BAD, "Invalid arguments");
-  imap4d_bye0 (OK, command);
+  imap4d_bye_command (OK, command);
   return 0;
 }
